==> cyphesis-cpp_0.5.15.orig.tar.gz: cyphesis-0.5.15/server/CorePropertyManager.h <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2006 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: CorePropertyManager.h,v 1.4 2006-10-26 00:48:14 alriddoch Exp $

#ifndef SERVER_CORE_PROPERTY_MANAGER_H
#define SERVER_CORE_PROPERTY_MANAGER_H

#include "common/PropertyManager.h"

#include <map>

class PropertyFactory;

typedef std::map<std::string, PropertyFactory *> PropertyFactoryDict;

/// \brief Property manager for the core server. Handles assigning properties
/// to entity instances in the world.
class CorePropertyManager : public PropertyManager {
  protected:
    // Data structure for factories and the like?
    std::map<std::string, PropertyFactory *> m_propertyFactories;
  public:
    CorePropertyManager();
    virtual ~CorePropertyManager();

    virtual PropertyBase * addProperty(Entity *, const std::string & name);
};

#endif // SERVER_CORE_PROPERTY_MANAGER_H

==> cyphesis-cpp_0.5.16.orig.tar.gz: cyphesis-0.5.16/server/CorePropertyManager.h <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2006 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: CorePropertyManager.h,v 1.5 2007-12-20 18:42:43 alriddoch Exp $

#ifndef SERVER_CORE_PROPERTY_MANAGER_H
#define SERVER_CORE_PROPERTY_MANAGER_H

#include "common/PropertyManager.h"

#include <map>

class PropertyKit;

typedef std::map<std::string, PropertyKit *> PropertyFactoryDict;

/// \brief Property manager for the core server. Handles assigning properties
/// to entity instances in the world.
class CorePropertyManager : public PropertyManager {
  protected:
    // Data structure for factories and the like?
    std::map<std::string, PropertyKit *> m_propertyFactories;
  public:
    CorePropertyManager();
    virtual ~CorePropertyManager();

    virtual PropertyBase * addProperty(Entity *, const std::string & name);
};

#endif // SERVER_CORE_PROPERTY_MANAGER_H
